RuleObject

Struct RuleObject 

pub struct RuleObject<'lt, Cx: CxType> { /* private fields */ }
An object dynamically representing an implementation of Rule.

Implementations

Source

impl<'lt, Cx: CxType> RuleObject<'lt, Cx>

pub fn new<T: Rule>(next: impl Into<Option<&'lt Self>>) -> Self

Creates a RuleObject for rule T, which may be followed by another RuleObject next.

pub const fn of<T: Rule>() -> &'lt Self

Creates an unbounded reference to a RuleObject for T.

pub fn name(&self) -> &str

The name of the rule.

pub fn pre_parse( &self, cx: ParseContext<'_, '_, Cx>, state: PreParseState, ) -> RuleParseResult<()>

Begins evaluating this rule, stopping when the lookahead buffer is full.