pub struct RuleObject<'lt, Cx: CxType> { /* private fields */ }Expand description
An object dynamically representing an implementation of Rule.
Implementations
Sourceimpl<'lt, Cx: CxType> RuleObject<'lt, Cx>
impl<'lt, Cx: CxType> RuleObject<'lt, Cx>
Sourcepub fn new<T: Rule>(next: impl Into<Option<&'lt Self>>) -> Self
pub fn new<T: Rule>(next: impl Into<Option<&'lt Self>>) -> Self
Creates a RuleObject for rule T, which may be followed by another RuleObject next.
Sourcepub const fn of<T: Rule>() -> &'lt Self
pub const fn of<T: Rule>() -> &'lt Self
Creates an unbounded reference to a RuleObject for T.
Sourcepub fn pre_parse(
&self,
cx: ParseContext<'_, '_, Cx>,
state: PreParseState,
) -> RuleParseResult<()>
pub fn pre_parse( &self, cx: ParseContext<'_, '_, Cx>, state: PreParseState, ) -> RuleParseResult<()>
Begins evaluating this rule, stopping when the lookahead buffer is full.